@@ -14,6 +14,7 @@ from whiskerrag_types.model import (
     TaskStatus,
     Tenant,
 )
+from whiskerrag_types.model.artifact_index import ArtifactIndex, ArtifactIndexCreate
 from whiskerrag_types.model.chunk import Chunk
 from whiskerrag_types.model.retrieval import (
     RetrievalByKnowledgeRequest,
@@ -21,6 +22,8 @@ from whiskerrag_types.model.retrieval import (
     RetrievalChunk,
     RetrievalRequest,
 )
+from whiskerrag_types.model.tag import Tag, TagCreate
+from whiskerrag_types.model.tagging import Tagging, TaggingCreate
 
 from .settings_interface import SettingsInterface
 
@@ -299,6 +302,107 @@ class DBPluginInterface(ABC):
     async def agent_invoke(self, params: Any) -> AsyncIterator[Any]:
         pass
 
+    # =================== tag ===================
+    @abstractmethod
+    async def add_tag_list(
+        self, tenant_id: str, tag_list: List[TagCreate]
+    ) -> List[Tag]:
+        pass
+
+    @abstractmethod
+    async def get_tag_list(
+        self, tenant_id: str, page_params: PageQueryParams[Tag]
+    ) -> PageResponse[Tag]:
+        pass
+
+    @abstractmethod
+    async def get_tag_by_id(self, tenant_id: str, tag_id: str) -> Union[Tag, None]:
+        pass
+
+    @abstractmethod
+    async def delete_tag_by_id(self, tenant_id: str, tag_id: str) -> Union[Tag, None]:
+        pass
+
+    @abstractmethod
+    async def update_tag_name_description(
+        self,
+        tenant_id: str,
+        tag_id: str,
+        name: Optional[str],
+        description: Optional[str],
+    ) -> Tag:
+        pass
+
+    # =================== tagging ===================
+    @abstractmethod
+    async def add_tagging_list(
+        self, tenant_id: str, tagging_list: List[TaggingCreate]
+    ) -> List[Tagging]:
+        pass
+
+    @abstractmethod
+    async def get_tagging_list(
+        self, tenant_id: str, page_params: PageQueryParams[Tagging]
+    ) -> PageResponse[Tagging]:
+        pass
+
+    @abstractmethod
+    async def delete_tagging_by_id(
+        self, tenant_id: str, tagging_id: str
+    ) -> Union[Tagging, None]:
+        pass
+
+    # =================== artifacts ===================
+    """
+    ArtifactIndex 仓储层抽象接口
+    """
+
+    @abstractmethod
+    async def add_artifact_list(
+        self, artifact_list: List[ArtifactIndexCreate]
+    ) -> List[ArtifactIndex]:
+        """
+        批量添加 artifact 记录
+        返回实际插入成功的 ArtifactIndex 记录列表
+        """
+        pass
+
+    @abstractmethod
+    async def get_artifact_list(
+        self, page_params: PageQueryParams[ArtifactIndex]
+    ) -> PageResponse[ArtifactIndex]:
+        """
+        分页获取 artifact 列表
+        """
+        pass
+
+    @abstractmethod
+    async def get_artifact_by_id(self, artifact_id: str) -> Union[ArtifactIndex, None]:
+        """
+        根据 artifact_id 获取 ArtifactIndex 详情
+        """
+        pass
+
+    @abstractmethod
+    async def delete_artifact_by_id(
+        self, artifact_id: str
+    ) -> Union[ArtifactIndex, None]:
+        """
+        根据 artifact_id 删除 ArtifactIndex 记录
+        返回被删除的记录（如果存在的话）
+        """
+        pass
+
+    @abstractmethod
+    async def update_artifact_space_id(
+        self, artifact_id: str, new_space_id: str
+    ) -> Union[ArtifactIndex, None]:
+        """
+        更新 artifact 的 space_id 绑定
+        返回更新后的 ArtifactIndex 记录（如果存在的话）
+        """
+        pass
+
     # =================== dashboard ===================
     # TODO: add dashboard related methods
 
