@@ -15,6 +15,9 @@ class Resource(str, Enum):
     RULE = "rule"
     PUBLIC = "public"
     WEBHOOK = "webhook"
+    TAG = "tag"
+    TAGGING = "tagging"
+    ARTIFACT = "artifact"
 
 
 class Action(str, Enum):
